@@ -1,4 +1,4 @@
-# Copyright (c) 2018, 2019  Peter Pentchev
+# Copyright (c) 2018 - 2020  Peter Pentchev
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -22,8 +22,7 @@
 # OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 # SUCH DAMAGE.
 
-"""
-The command-line interface to the confget module: specify some parameters
+"""The command-line interface to the confget module: specify some parameters
 through command-line options, then display variable values or names.
 """
 
@@ -37,7 +36,7 @@ from . import defs
 from . import format as fmt
 
 try:
-    from typing import List, Optional
+    from typing import List, Optional  # noqa: H301
 
     _TYPING_USED = (defs, List, Optional)
 except ImportError:
@@ -46,8 +45,7 @@ except ImportError:
 
 class MainConfig(fmt.FormatConfig):
     # pylint: disable=too-few-public-methods,too-many-instance-attributes
-    """
-    Extend the format config class with some output settings.
+    """Extend the format config class with some output settings.
 
     Add the following settings:
     - check_only (boolean): only check whether a variable is defined
@@ -72,7 +70,7 @@ class MainConfig(fmt.FormatConfig):
         varnames,  # type: List[str]
     ):  # type: (...) -> None
         # pylint: disable=too-many-arguments,too-many-locals
-        """ Store the specified configuration values. """
+        """Store the specified configuration values."""
         super(MainConfig, self).__init__(
             filename=filename,
             list_all=list_all,
@@ -93,17 +91,13 @@ class MainConfig(fmt.FormatConfig):
 
 def version():
     # type: () -> None
-    """
-    Display program version information.
-    """
+    """Display program version information."""
     print("confget " + defs.VERSION_STRING)
 
 
 def features(name):
     # type: (Optional[str]) -> None
-    """
-    Display a list of the features supported by the program.
-    """
+    """Display a list of the features supported by the program."""
     if name is None:
         print(
             " ".join(
@@ -122,7 +116,7 @@ def features(name):
 
 def output_check_only(cfg, data):
     # type: (MainConfig, defs.ConfigData) -> None
-    """ Check whether the variable is present. """
+    """Check whether the variable is present."""
     if cfg.section not in data:
         sys.exit(1)
     elif cfg.varnames[0] not in data[cfg.section]:
@@ -132,14 +126,14 @@ def output_check_only(cfg, data):
 
 def output_vars(cfg, data):
     # type: (MainConfig, defs.ConfigData) -> None
-    """ Output the variable values. """
+    """Output the variable values."""
     for vitem in fmt.filter_vars(cfg, data):
         print(vitem.output_full)
 
 
 def output_sections(data):
     # type: (defs.ConfigData) -> None
-    """ Output the section names. """
+    """Output the section names."""
     for name in sorted(data.keys()):
         if name != "":
             print(name)
@@ -147,9 +141,7 @@ def output_sections(data):
 
 def validate_options(args, backend_name):
     # type: (argparse.Namespace, str) -> None
-    """
-    Make sure the command-line options are not used in an invalid combination.
-    """
+    """Detect invalid combinations of command-line options."""
     query_sections = args.query == "sections"
 
     if args.list_all or query_sections:
@@ -172,7 +164,7 @@ def validate_options(args, backend_name):
 
 def check_option_conflicts(args):
     # type: (argparse.Namespace) -> None
-    """ Make sure that the command-line options do not conflict. """
+    """Make sure that the command-line options do not conflict."""
     total = (
         int(args.query is not None)
         + int(args.match_var_names)
@@ -188,9 +180,7 @@ def check_option_conflicts(args):
 
 def main():
     # type: () -> None
-    """
-    The main program: parse arguments, do things.
-    """
+    """The main program: parse arguments, do things."""
     parser = argparse.ArgumentParser(
         prog="confget",
         usage="""
