@@ -1,4 +1,4 @@
-# Copyright (c) 2018, 2019  Peter Pentchev <roam@ringlet.net>
+# Copyright (c) 2018 - 2020  Peter Pentchev <roam@ringlet.net>
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -22,9 +22,7 @@
 # OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 # SUCH DAMAGE.
 
-"""
-A confget backend for reading INI-style files.
-"""
+"""A confget backend for reading INI-style files."""
 
 import io
 import re
@@ -35,7 +33,7 @@ from .. import defs
 from . import abstract
 
 try:
-    from typing import Callable, Dict, Match, NamedTuple, Pattern
+    from typing import Callable, Dict, Match, NamedTuple, Pattern  # noqa: H301
 
     _TYPING_USED = (defs, Dict)
 
@@ -62,7 +60,7 @@ except ImportError:
 
 class INIBackend(abstract.Backend):
     # pylint: disable=too-few-public-methods
-    """ Parse INI-style configuration files. """
+    """Parse INI-style configuration files."""
 
     def __init__(self, cfg, encoding="UTF-8"):
         # type: (INIBackend, defs.Config, str) -> None
@@ -94,7 +92,7 @@ class INIBackend(abstract.Backend):
             cfg,  # type: defs.Config
             res,  # type: defs.ConfigData
         ):  # type: (...) -> None
-            """ Handle a section heading: store the name. """
+            """Handle a section heading: store the name."""
             state["section"] = match.group("name")
             if state["section"] not in res:
                 res[state["section"]] = {}
@@ -108,7 +106,7 @@ class INIBackend(abstract.Backend):
             _cfg,  # type: defs.Config
             _res,  # type: defs.ConfigData
         ):  # type: (...) -> None
-            """ Handle a comment line: ignore it. """
+            """Handle a comment line: ignore it."""
             pass  # pylint: disable=unnecessary-pass
 
         def handle_variable(
@@ -117,7 +115,7 @@ class INIBackend(abstract.Backend):
             _cfg,  # type: defs.Config
             res,  # type: defs.ConfigData
         ):  # type: (...) -> None
-            """ Handle an assignment: store, check for a continuation. """
+            """Handle an assignment: store, check for a continuation."""
             state["name"] = match.group("name")
             state["value"] = match.group("value")
             state["cont"] = match.group("cont")
