@@ -1,4 +1,4 @@
-# Copyright (c) 2018, 2019  Peter Pentchev <roam@ringlet.net>
+# Copyright (c) 2018 - 2020  Peter Pentchev <roam@ringlet.net>
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -22,15 +22,20 @@
 # OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 # SUCH DAMAGE.
 
-"""
-Filter and format a subset of the configuration variables.
-"""
+"""Filter and format a subset of the configuration variables."""
 
 import fnmatch
 import re
 
 try:
-    from typing import Callable, Dict, Iterable, NamedTuple, List, Optional
+    from typing import (
+        Callable,
+        Dict,
+        Iterable,
+        NamedTuple,
+        List,
+        Optional,
+    )  # noqa: H301
 
     _TYPING_USED = (Callable, Dict, Iterable, List, Optional)
 
@@ -57,8 +62,7 @@ from . import defs
 
 class FormatConfig(defs.Config):
     # pylint: disable=too-few-public-methods,too-many-instance-attributes
-    """
-    Extend the config class with some output settings.
+    """Extend the config class with some output settings.
 
     Add the following settings:
     - list_all (boolean): list all variables, not just a subset
@@ -92,7 +96,7 @@ class FormatConfig(defs.Config):
         shell_escape=False,  # type: bool
     ):  # type: (...) -> None
         # pylint: disable=too-many-arguments
-        """ Store the specified configuration values. """
+        """Store the specified configuration values."""
         super(FormatConfig, self).__init__(
             filename=filename,
             section=section,
@@ -138,7 +142,8 @@ class FormatConfig(defs.Config):
 
 def get_check_function(cfg, patterns):
     # type: (FormatConfig, List[str]) -> Callable[[str], bool]
-    """
+    """Get a predicate for displayed variables.
+
     Get a function that determines whether a variable name should be
     included in the displayed subset.
     """
@@ -147,14 +152,14 @@ def get_check_function(cfg, patterns):
 
         def check_re_vars(key):
             # type: (str) -> bool
-            """ Check that the key matches any of the specified regexes. """
+            """Check that the key matches any of the specified regexes."""
             return any(rex.search(key) for rex in re_vars)
 
         return check_re_vars
 
     def check_fn_vars(key):
         # type: (str) -> bool
-        """ Check that the key matches any of the specified patterns. """
+        """Check that the key matches any of the specified patterns."""
         return any(fnmatch.fnmatch(key, pattern) for pattern in patterns)
 
     return check_fn_vars
@@ -162,7 +167,7 @@ def get_check_function(cfg, patterns):
 
 def get_varnames(cfg, sect_data):
     # type: (FormatConfig, Dict[str, str]) -> Iterable[str]
-    """ Get the variable names that match the configuration requirements. """
+    """Get the variable names that match the configuration requirements."""
     if cfg.list_all:
         varnames = sect_data.keys()  # type: Iterable[str]
     elif cfg.match_var_names:
@@ -180,9 +185,8 @@ def get_varnames(cfg, sect_data):
 
 def filter_vars(cfg, data):
     # type: (FormatConfig, defs.ConfigData) -> Iterable[FormatOutput]
-    """
-    Filter the variables in the configuration file according to
-    the various criteria specified in the configuration.
+    """Filter the variables according to the specified criteria.
+
     Return an iterable of FormatOutput structures allowing the caller to
     process the variable names and values in various ways.
     """
