@@ -1,6 +1,6 @@
 #!/usr/bin/python3
 #
-# Copyright (c) 2019  Peter Pentchev <roam@ringlet.net>
+# Copyright (c) 2019, 2020  Peter Pentchev <roam@ringlet.net>
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -24,9 +24,7 @@
 # OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 # SUCH DAMAGE.
 
-"""
-Setup infrastructure for confget, the configuration file parser.
-"""
+"""Setup infrastructure for confget, the configuration file parser."""
 
 import re
 import setuptools  # type: ignore
@@ -46,7 +44,7 @@ RE_VERSION = r"""^
 
 def get_version():
     # type: () -> str
-    """ Get the version string from the module's __init__ file. """
+    """Get the version string from the module's __init__ file."""
     found = None
     re_semver = re.compile(RE_VERSION, re.X)
     with open("confget/defs.py") as init:
@@ -63,7 +61,7 @@ def get_version():
 
 def get_long_description():
     # type: () -> str
-    """ Get the package long description from the README file. """
+    """Get the package long description from the README file."""
     with open("README.md") as readme:
         return readme.read()
 
@@ -109,5 +107,12 @@ setuptools.setup(
         "Topic :: Utilities",
     ],
     entry_points={"console_scripts": ["confget=confget.__main__:main"]},
+    test_requires=[
+        'configparser;python_version<"3"',
+        "ddt",
+        'pathlib2;python_version<"3"',
+        "pytest",
+        "six",
+    ],
     zip_safe=True,
 )
